@@ -39,6 +39,7 @@ module Schleuder
     rescue => exc
       begin
         Schleuder.logger.fatal(exc.message_with_backtrace, message)
+        # Don't use FatalError here to reduce dependency on other code.
         say I18n.t('errors.fatalerror')
       rescue => e
         # Give users a clue what to do in case everything blows up.
@@ -108,9 +109,9 @@ module Schleuder
       end
 
       if ActiveRecord::SchemaMigration.table_exists?
-        say `cd #{root_dir} && rake db:migrate`
+        say shellexec("cd #{root_dir} && rake db:migrate")
       else
-        say `cd #{root_dir} && rake db:schema:load`
+        say shellexec("cd #{root_dir} && rake db:init")
         if Conf.database['adapter'].match(/sqlite/)
           say "NOTE: The database was prepared using sqlite. If you prefer to use a different DBMS please edit the 'database'-section in /etc/schleuder/schleuder.yml, create the database, install the corresponding ruby-library (e.g. `gem install mysql`) and run this current command again"
         end
@@ -301,8 +302,18 @@ Please notify the users and admins of this list of these changes.
           return nil
         end
       end
+
+      def shellexec(cmd)
+        result = `#{cmd} 2>&1`
+        if $?.exitstatus > 0
+          exit $?.exitstatus
+        end
+        result
+      end
     end
+
     private
+
     def work_on_lists(subj, list=nil)
       selected_lists = if list.nil?
         List.all
