@@ -26,4 +26,12 @@ describe 'lists via api' do
     expect(JSON.parse(last_response.body)['email']).to eq list.email
   end
 
+  it 'correctly finds a list by email-address that starts with a number' do
+    authorize!
+    list = create(:list, email: "9list@hostname")
+    get "lists/#{list.email}.json"
+    expect(last_response.status).to be 200
+    expect(JSON.parse(last_response.body)['email']).to eq list.email
+  end
+
 end
